# @Karlsruher
* is a robot on Twitter ([Link](https://twitter.com/Karlsruher))
* retweets mentions from its followers when they apply some rules
---

## Social Networking Feature
Followers can share and relay information via the Robot without the need to follow each other directly.



## Technology
The software works with any Twitter account, so one may have simply own ideas...

Hopefully clean-coded, self-explaining and reusable [Python 3](https://www.python.org/) using [Tweepy](https://www.tweepy.org/) as Twitter client and [SQLite](https://www.sqlite.org/) as database brain.

## Read on
* [Insights for Developers](README.developer.md)
* [Setup instructions](README.setup.md)
* [Der @Karlsruher auf Twitter](https://twitter.com/Karlsruher)
* [Nutzeranleitung des @Karlsruhers auf Deutsch](https://bit.ly/2FHcp8A)
